// Sample dataset
const dataset = [
  { label: 'Category 1', value: 30 },
  { label: 'Category 2', value: 50 },
  { label: 'Category 3', value: 20 },
  { label: 'Category 4', value: 40 },
  { label: 'Category 5', value: 10 }
];

// Set up chart dimensions
const width = 400;
const height = 300;
const margin = { top: 20, right: 30, bottom: 30, left: 40 };
const chartWidth = width - margin.left - margin.right;
const chartHeight = height - margin.top - margin.bottom;

// Create the SVG element
const svg = d3.select('#chart')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

// Create the chart group
const chart = svg.append('g')
  .attr('transform', `translate(${margin.left}, ${margin.top})`);

// Create x and y scales
const xScale = d3.scaleBand()
  .domain(dataset.map(d => d.label))
  .range([0, chartWidth])
  .padding(0.2);

const yScale = d3.scaleLinear()
  .domain([0, d3.max(dataset, d => d.value)])
  .range([chartHeight, 0]);

// Create and append the bars
chart.selectAll('rect')
  .data(dataset)
  .enter()
  .append('rect')
  .attr('x', d => xScale(d.label))
  .attr('y', d => yScale(d.value))
  .attr('width', xScale.bandwidth())
  .attr('height', d => chartHeight - yScale(d.value))
  .attr('fill', 'steelblue');

// Add x-axis
chart.append('g')
  .attr('transform', `translate(0, ${chartHeight})`)
  .call(d3.axisBottom(xScale));

// Add y-axis
chart.append('g')
  .call(d3.axisLeft(yScale));
